colour.models.dataset.dci_p3 Module — Colour 0.3.0 documentation

# colour.models.dataset.dci_p3 Module

## DCI-P3 Colourspace

Defines the DCI-P3 colourspace:

- `DCI_P3_COLOURSPACE`.

See also

RGB Colourspaces IPython Notebook

References

[1] | http://www.hp.com/united-states/campaigns/workstations/pdfs/lp2480zx-dci–p3-emulation.pdf (Last accessed 24 February 2014)

`colour.models.dataset.dci_p3.` `DCI_P3_PRIMARIES` = array([[ 0.68 , 0.32 ], [ 0.265, 0.69 ], [ 0.15 , 0.06 ]])

  DCI-P3 colourspace primaries.

  DCI_P3_PRIMARIES : ndarray, (3, 2)

`colour.models.dataset.dci_p3.` `DCI_P3_WHITEPOINT` = (0.314, 0.351)

  DCI-P3 colourspace whitepoint.

  DCI_P3_WHITEPOINT : tuple

`colour.models.dataset.dci_p3.` `DCI_P3_TO_XYZ_MATRIX` = array([[ 0.44516982, 0.27713441, 0.17228267], [ 0.20949168, 0.72159525, 0.06891307], [ 0. , 0.04706056, 0.90735539]])

  DCI-P3 colourspace to CIE XYZ colourspace matrix.

  DCI_P3_TO_XYZ_MATRIX : array_like, (3, 3)

`colour.models.dataset.dci_p3.` `XYZ_TO_DCI_P3_MATRIX` = array([[ 2.72539401, -1.01800301, -0.44016319], [-0.79516803, 1.68973207, 0.02264719], [ 0.04124189, -0.08763902, 1.10092938]])

  CIE XYZ colourspace to DCI-P3 colourspace matrix.

  XYZ_TO_DCI_P3_MATRIX : array_like, (3, 3)

`colour.models.dataset.dci_p3.` `DCI_P3_TRANSFER_FUNCTION`(x)

  Transfer function from linear to DCI-P3 colourspace.

  DCI_P3_TRANSFER_FUNCTION : object

`colour.models.dataset.dci_p3.` `DCI_P3_INVERSE_TRANSFER_FUNCTION`(x)

  Inverse transfer function from DCI-P3 colourspace to linear.

  DCI_P3_INVERSE_TRANSFER_FUNCTION : object

`colour.models.dataset.dci_p3.` `DCI_P3_COLOURSPACE` = <colour.models.rgb_colourspace.RGB_Colourspace object at 0x102e1dad0>

  DCI-P3 colourspace.

  DCI_P3_COLOURSPACE : RGB_Colourspace